@@ -53,6 +53,7 @@ from pg8000.core import (
     ver,
 )
 from pg8000.exceptions import DatabaseError, Error, InterfaceError
+from pg8000.types import Range
 
 
 __version__ = ver
@@ -114,7 +115,7 @@ BINARY = bytes
 
 
 def PgDate(year, month, day):
-    """Constuct an object holding a date value.
+    """Construct an object holding a date value.
 
     This function is part of the `DBAPI 2.0 specification
     <http://www.python.org/dev/peps/pep-0249/>`_.
@@ -159,7 +160,7 @@ def DateFromTicks(ticks):
 
 
 def TimeFromTicks(ticks):
-    """Construct an objet holding a time value from the given ticks value
+    """Construct an object holding a time value from the given ticks value
     (number of seconds since the epoch).
 
     This function is part of the `DBAPI 2.0 specification
@@ -205,8 +206,8 @@ def connect(
     tcp_keepalive=True,
     application_name=None,
     replication=None,
+    sock=None,
 ):
-
     return Connection(
         user,
         host=host,
@@ -220,6 +221,7 @@ def connect(
         tcp_keepalive=tcp_keepalive,
         application_name=application_name,
         replication=replication,
+        sock=sock,
     )
 
 
@@ -511,7 +513,6 @@ class Cursor:
         operation = f"CALL {procname}(" + ", ".join(["%s" for _ in args]) + ")"
 
         try:
-
             statement, vals = convert_paramstyle("format", operation, args)
 
             self._context = self._c.execute_unnamed(statement, vals=vals)
@@ -947,6 +948,7 @@ __all__ = [
     "PGInterval",
     "ProgrammingError",
     "ROWID",
+    "Range",
     "STRING",
     "TEXT",
     "TEXT_ARRAY",
